/*
 	File:        PageOptions.cpp
  Description: Main menu page
  Program:     BlockOut
  Author:      Jean-Luc PONS

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
*/

#include "Menu.h"

void PageOptions::Prepare(int iParam,void *pParam) {
  nbItem  = 9;
  selItem = 0;
}

void PageOptions::Render() {
  
  int size;

  mParent->RenderTitle("OPTIONS");
  mParent->RenderText(0,0,(selItem==0),"Controls          ");
  mParent->RenderText(0,1,(selItem==1),"HTTP              ");

  mParent->RenderText(0,3,(selItem==2),"Sound            :");
  if( mParent->GetSetup()->GetSound() )
    mParent->RenderText(19,3,FALSE,"Enabled");
  else
    mParent->RenderText(19,3,FALSE,"Disabled");
  mParent->RenderText(0,4,(selItem==3),  "FullScreen       :");
  if( mParent->GetSetup()->GetFullScreen() ) {
    mParent->RenderText(19,4,FALSE,"Enabled");
    mParent->RenderText(0,5,(selItem==4),"Screen Size      :");
  } else {
    mParent->RenderText(19,4,FALSE,"Disabled");
    mParent->RenderText(0,5,(selItem==4),"Window Size      :");
  }
  size = mParent->GetSetup()->GetWindowSize();
  mParent->RenderText(19,5,FALSE,(char *)mParent->GetSetup()->GetResName(size));  

  mParent->RenderText(0,6,(selItem==5),"Rotation Speed   :");
  mParent->RenderText(19,6,FALSE,"S[           ]F");
  int aSpeed = mParent->GetSetup()->GetAnimationSpeed();
  int i;
  for(i=0;i<=aSpeed;i++)
    mParent->RenderText(21+i,6,TRUE,".");
  for(;i<=ASPEED_FAST;i++)
    mParent->RenderText(21+i,6,FALSE,".");

  mParent->RenderText(0,7,(selItem==6),"Transparent face :");
  mParent->RenderText(19,7,FALSE,"T[           ]O");
  int fTrans = mParent->GetSetup()->GetTransparentFace();
  for(i=0;i<=fTrans;i++)
    mParent->RenderText(21+i,7,TRUE,".");
  for(;i<=FTRANS_MAX;i++)
    mParent->RenderText(21+i,7,FALSE,".");

  mParent->RenderText(0,8,(selItem==7),"Style            :");
  mParent->RenderText(19,8,FALSE,(char *)mParent->GetSetup()->GetStyleName());

  mParent->RenderText(0,9,(selItem==8),"Sound preset     :");
  mParent->RenderText(19,9,FALSE,(char *)mParent->GetSetup()->GetSoundTypeName());

}

int PageOptions::Process(BYTE *keys,float fTime) {

  int exitValue = 0;

  ProcessDefault(keys,fTime);

  if( keys[SDLK_RETURN] ) {
    switch( selItem ) {
      case 0: // Controls
        mParent->ToPage(&mParent->controlsPage);
        break;
      case 1: // HTTP
        mParent->ToPage(&mParent->httpPage);
        break;
      case 2: // Sound
      case 3: // FullScreen mode
      case 4: // Window size
      case 5: // Rotation speed
      case 6: // Transparent face
      case 7: // Style
      case 8: // Sound preset
        exitValue = ProcessKey(SDLK_RIGHT);
        break;
    }
    keys[SDLK_RETURN] = 0;
  }

  if( keys[SDLK_LEFT]  ) {
    exitValue = ProcessKey(SDLK_LEFT);
    keys[SDLK_LEFT] = 0;
  }

  if( keys[SDLK_RIGHT]  ) {
    exitValue = ProcessKey(SDLK_RIGHT);
    keys[SDLK_RIGHT] = 0;
  }

  if( keys[SDLK_ESCAPE] ) {
     mParent->ToPage(&mParent->mainMenuPage);
     keys[SDLK_ESCAPE] = 0;
  }

  return exitValue;
}

int PageOptions::ProcessKey(int key) {

   int x;
   int exitValue = 0;

    switch( selItem ) {
      case 2: // Sound
        if( key==SDLK_RIGHT || key==SDLK_LEFT ) {
          BOOL sound = mParent->GetSetup()->GetSound();
          mParent->GetSetup()->SetSound(!sound);
          mParent->GetSound()->SetEnable(!sound);
          mParent->GetSound()->PlayBlub();
        }
      break;
      case 3: // Fullscreen mode
        if( key==SDLK_RIGHT || key==SDLK_LEFT ) {
          BOOL fs = mParent->GetSetup()->GetFullScreen();
          mParent->GetSetup()->SetFullScreen(!fs);
          exitValue = 3; // Update full screen
        }
      break;
      case 4: // Window size
        switch( key ) {
          case SDLK_RIGHT:
            x = mParent->GetSetup()->GetWindowSize();
            if( x<RES_1280x1024 )
              mParent->GetSetup()->SetWindowSize(x+1);
            else
              mParent->GetSetup()->SetWindowSize(RES_640x480);
            exitValue = 2; // Resize
            break;
          case SDLK_LEFT:
            x = mParent->GetSetup()->GetWindowSize();
            if( x>RES_640x480 )
              mParent->GetSetup()->SetWindowSize(x-1);
            else
              mParent->GetSetup()->SetWindowSize(RES_1280x1024);
            exitValue = 2; // Resize
            break;
        }
      break;
      case 5: // Rotation speed
        switch( key ) {
          case SDLK_RIGHT:
            x = mParent->GetSetup()->GetAnimationSpeed();
            if( x<ASPEED_FAST )
              mParent->GetSetup()->SetAnimationSpeed(x+1);
            else
              mParent->GetSetup()->SetAnimationSpeed(ASPEED_SLOW);
            break;
          case SDLK_LEFT:
            x = mParent->GetSetup()->GetAnimationSpeed();
            if( x>ASPEED_SLOW )
              mParent->GetSetup()->SetAnimationSpeed(x-1);
            else
              mParent->GetSetup()->SetAnimationSpeed(ASPEED_FAST);
            break;
        }
      break;
      case 6: // Transparent face
        switch( key ) {
          case SDLK_RIGHT:
            x = mParent->GetSetup()->GetTransparentFace();
            if( x<FTRANS_MAX )
              mParent->GetSetup()->SetTransparentFace(x+1);
            else
              mParent->GetSetup()->SetTransparentFace(FTRANS_MIN);
            break;
          case SDLK_LEFT:
            x = mParent->GetSetup()->GetTransparentFace();
            if( x>FTRANS_MIN )
              mParent->GetSetup()->SetTransparentFace(x-1);
            else
              mParent->GetSetup()->SetTransparentFace(FTRANS_MAX);
            break;
        }
      break;
      case 7: // Game style
        switch( key ) {
          case SDLK_RIGHT:
            x = mParent->GetSetup()->GetStyle();
            if( x<STYLE_ARCADE )
              mParent->GetSetup()->SetStyle(x+1);
            else
              mParent->GetSetup()->SetStyle(STYLE_CLASSIC);
            break;
          case SDLK_LEFT:
            x = mParent->GetSetup()->GetStyle();
            if( x>STYLE_CLASSIC )
              mParent->GetSetup()->SetStyle(x-1);
            else
              mParent->GetSetup()->SetStyle(STYLE_ARCADE);
            break;
        }
      break;
      case 8: // Sound preset
        switch( key ) {
          case SDLK_RIGHT:
            x = mParent->GetSetup()->GetSoundType();
            if( x<SOUND_BLOCKOUT )
              mParent->GetSetup()->SetSoundType(x+1);
            else
              mParent->GetSetup()->SetSoundType(SOUND_BLOCKOUT2);
            break;
          case SDLK_LEFT:
            x = mParent->GetSetup()->GetSoundType();
            if( x>SOUND_BLOCKOUT2 )
              mParent->GetSetup()->SetSoundType(x-1);
            else
              mParent->GetSetup()->SetSoundType(SOUND_BLOCKOUT);
            break;
        }
      break;
    }

    return exitValue;

}
